/*
 * Project name:
     ADC_Test (Demonstration of SPI communication with AD converter)
 * Copyright:
     (c) MikroElektronika, 2011.
 * Revision History:
     20110414:
       - initial release (FJ);
 * Description:
     This project is a simple demonstration of working with the 2.7V 4-Channel
     12-bit A/D Converter(MCP3204) with SPI Serial Interface.
     The values measured on Channel 0 are being displayed on P3 LEDs in the 8-levels mode.
 * Test configuration:
     MCU:             AT89S8253
                      http://www.atmel.com/dyn/resources/prod_documents/doc3286.pdf
     Dev.Board:       UNI-DS6
                      http://www.mikroe.com/eng/products/view/669/uni-ds6-development-system/
     Oscillator:      External Clock 10.0000 MHz
     Ext. Modules:    Lcd 2x16
                      http://www.mikroe.com/en/tools/components/#other
     SW:              mikroC PRO for 8051
                      http://www.mikroe.com/en/compilers/mikroc/8051/
 * NOTES:
     - Turn on SPI1 switches on SW14.1, SW14.1 and SW14.3. (board specific)
     - Turn on ADC-CS on SW13.7. (board specific)
     - Turn on PORTD LEDs on SW12.4. (board specific)
     - Turn on +5V voltage reference on SW12.7. (board specific)
*/

# include <built_in.h>

// EasyADC module connections
sbit Chip_Select at P2_0_bit;
// End EasyADC module connections

unsigned int  measurement, lastValue;

void Init() {
  lastValue = 1;                                 // Initialize and make them
  measurement = 0;                               // different

  // Init SPI
  SPI1_Init();
  Chip_Select= 1;                                // SetBit(P2,0)
}

unsigned int getADC(unsigned short channel) {    // Returns 0..4095
  unsigned int tmp;
  Chip_Select =0;                                // Select MCP3204
  SPI1_Write(0x06);                              // SPI communication using 8-bit segments
  channel = channel << 6;                        // Bits 7 & 6 define ADC input
  tmp = SPI1_Read(channel) & 0x0F;
  tmp = tmp << 8;                                // Get ADC value
  tmp |= SPI1_Read(0);
  Chip_Select =1;
  return tmp;
}

void processValue(unsigned int pv) {             // Writes measured values to LEDs in the 8-levels mode
  if (lastValue != pv) {                         // Write value only if different than previous

    lastValue = pv;

    // Converting the measured values into 8-levels mode
    pv = (pv >> 9) + 1;
    pv = (1 << pv) - 1;

    P3 = Lo(pv);                                 // Displaying the result on the P3
  }
}

// main procedure
void main() {
  Init();                                        // Initialize SPI
  while (1) {
    measurement = getADC(0);                     // Get ADC result from Channel 0
    ProcessValue(measurement);                   // Writing measured values to LEDs in the 8-levels mode
    Delay_ms(100);                               // Wait 100ms
  }
}
