/*
 * Project name:
     DEMO (Simple demonstration of the GLCD Library functions)
 * Copyright:
     (c) Mikroelektronika, 2011.
 * Description:
     This is a simple demonstration of the GLCD library routines:
     - Init and Clear (pattern fill)
     - Image display
 * Test configuration:
     MCU:             LPC2214
     Dev.Board:       UNIDS6
                      http://www.mikroe.com/eng/products/view/669/uni-ds6-development-system/
     Oscillator:      14.74568MHz (cclk = 58.98272MHz, Fcco = 235.93088 MHz)
     Ext. Modules:    -
     SW:              KEIL uVision v4.10
 * NOTES:
   - Turn ON the GLCD Backlight at SW18.8
	 - Turn ON SW17.1 - SW17.8 (data lines). Be sure to pull-down data lines!
	 - Turn ON SW18.1 - SW18.6 (ctrl lines). Be sure to pull-up the CS1\ and CS2\ lines!
*/


#include <LPC22XX.H>

#include "Glcd.h"
#include "bmp_maska.h"
#include "Utility.h"


unsigned char
	ii;

char
	*someText;




int main (void)
{
	PINSEL0 = 0;
	PINSEL1 = 0;
	PINSEL2 &= 0x0000000C;
	PINSEL2 |= 0x00000030;
	DelayProc(0.2 * CCLOCK);


	IODIR0 = 0;
	Glcd_Init(&IOPIN0,	// Control lines Port
						&IOPIN2,	// Data Lines Port
						2,				// CS1#
						3,				// CS2#
						4,				// RS
						5,				// R/W#
						7,				// RST
						6,				// EN
						0);			// D0 data line position


	while (1)
	{
		Glcd_Fill(0x00);

		Glcd_Image( maska_bmp );
		DelayProc(1.0 * CCLOCK);

		Glcd_Fill(0x00);

		Glcd_Line(120,1, 5,60, 1);
		Glcd_Line(12,42, 5,60, 1);
		DelayProc(0.5 * CCLOCK);

		Glcd_Rectangle(12,20, 93,57, 1);
		DelayProc(0.5 * CCLOCK);

		Glcd_Line(120,12, 12,60, 1);
		DelayProc(0.5 * CCLOCK);

		Glcd_H_Line(5,15, 6, 1);
		Glcd_Line(0,12, 120,60, 1);
		Glcd_V_Line(7,63, 127, 1);
		DelayProc(0.5 * CCLOCK);

		for (ii = 1; ii <= 10; ii++)
			Glcd_Circle(63,32, 3*ii, 1);
		DelayProc(0.5 * CCLOCK);

		Glcd_Box(12,20, 70,57, 2);
		DelayProc(0.5 * CCLOCK);

		someText = "BIG:ONE";
		Glcd_Write_Text(someText, 5,3, 2);
		DelayProc(0.5 * CCLOCK);

		someText = "SMALL:NOT:SMALLER";
		Glcd_Write_Text(someText, 20,5, 1);
		DelayProc(0.5 * CCLOCK);
	}
}
