/*
 * Project name:
     DEMO (MMC Library Example)
 * Copyright:
     (c) MikroElektronika, 2011.
 * Description:
     MMC library test. Upon flashing, insert a MMC/SD card into the	socket,
	 start the USART Terminal, then reset the MCU (you should receive
     the "Init-OK" message). Then, you can experiment with MMC read and write
     functions, and observe the results through the terminal receive panel window.
 * Test configuration:
     MCU:             LPC2214
     Dev.Board:       UNIDS6
                      http://www.mikroe.com/eng/products/view/669/uni-ds6-development-system/
     Oscillator:      14.74568MHz (cclk = 58.98272MHz, Fcco = 235.93088 MHz)
     Ext. Modules:    - 
     SW:              KEIL uVision v4.10
 * NOTES:
     - Be sure to connect the USB cable to the USB UART 1 communication port and to turn ON switches SW13.1 and SW13.2.
     - Start USART terminal adjusted to 38400 bps, 8 bit, no parity.
     - This example should work both for MMC and SD media types!
     - This is NOT an example for working with FILES on a MMC/SD memory module!
	 - Turn ON switches SW13.8, SW14.1, SW14.2 and SW14.3.
*/


#include <LPC22XX.H>

#include "Mmc_Lib.h"
#include "Serial.h"
#include "Utility.h"



// universal variables
unsigned long
	i;

// Variables for MMC routines
unsigned char
	WRdata[512],
	RDdata[512],
	CIDdata[16],
	CSDdata[16];



int main (void)
{
	PINSEL0 = 0;
	PINSEL1 = 0;
	PINSEL2 &= 0x0000000C;
	PINSEL2 |= 0x00000030;
	DelayProc(0.2 * CCLOCK);


	UART0_init(38400/*UART bps*/, 14745/*VPB clock [kHz]*/, length_8_bit, stop_bit_1, parity_disable, parity_odd);
	UART0_sendstring ("ARM Started.\n");

	//----------------------------------------------------------------------
	// Beffore all, we must initialise a MMC card
	//----------------------------------------------------------------------
	UART0_sendstring ("Init ");
	i = Mmc_Init(&IOPIN1, 25);
	if (i != 1)
		{
		// Error...
		UART0_sendstring ("Error.\n");
		while (1);
		}
	UART0_sendstring ("Ok.\n");

	//----------------------------------------------------------------------
	// Fill MMC buffer
	//----------------------------------------------------------------------
	for(i=0; i<=511; i++)
		WRdata[i] = 'E';

	//----------------------------------------------------------------------
	// Write sector
	//----------------------------------------------------------------------
	UART0_sendstring ("Write ");
	i = Mmc_Write_Sector(520+0, WRdata);
	if (i != 0)
		{
		// Error...
		UART0_sendstring ("Error.\n");
		while (1);
		}
	UART0_sendstring ("Ok.\n");

	//----------------------------------------------------------------------
	// Read same sector
	//----------------------------------------------------------------------
	UART0_sendstring ("Read ");
	i = Mmc_Read_Sector(520+0, RDdata);
	if (i != 0)
		{
		// Error...
		UART0_sendstring ("Error.\n");
		while (1);
		}
	UART0_sendstring ("Ok.\n");

	//----------------------------------------------------------------------
	// Compare data...
	//----------------------------------------------------------------------
	UART0_sendstring ("Compare ");
	for(i=0; i<=511; i++)
		if (WRdata[i] != RDdata[i])
			{
			// Error...
			UART0_sendstring ("Error.\n");
			while (1);
			}
	UART0_sendstring ("Success.\n");

	//----------------------------------------------------------------------
	// Read CID
	//----------------------------------------------------------------------
	if (Mmc_Read_Cid(CIDdata) == 0)
		{
		UART0_sendstring("=== MMC CID Data ===============================\n");
		for (i=0; i<=15; i++)
			{
			UART0_WriteNum(0, CIDdata[15-i]);
			if (i != 15)
				UART0_sendchar('-');
			}
		UART0_sendstring("\n");
		UART0_sendstring("================================================\n");
		}
	else
		{
		UART0_sendstring("=== MMC CID Data ===============================\n");
		UART0_sendstring("Error.\n");
		UART0_sendstring("================================================\n");
		}

	//----------------------------------------------------------------------
	// Read CSD
	//----------------------------------------------------------------------
	if (Mmc_Read_Csd(CSDdata) == 0)
		{
		UART0_sendstring("=== MMC CSD Data ===============================\n");
		for (i=0; i<=15; i++)
			{
			UART0_WriteNum(0, CSDdata[15-i]);
			if (i != 15)
				UART0_sendchar('-');
			}
		UART0_sendstring("\n");
		UART0_sendstring("================================================\n");
		}
	else
		{
		UART0_sendstring("=== MMC CSD Data ===============================\n");
		UART0_sendstring("Error.\n");
		UART0_sendstring("================================================\n");
		}


	while (1);
}
