// EEPROM 24AA01 read/write library


//--------------- Performs 24AA01 Init
void EEPROM_24AA01_Init() {
  TWI_Init(100000);
}

//--------------- Writes data to 24AA01 EEPROM - single location
void EEPROM_24AA01_WrSingle(unsigned short wAddr, unsigned short wData) {
    TWI_Start();                // issue I2C1 start signal
    TWI_Write(0xA2);            // send byte via I2C1  (command to 24cO2)
    TWI_Write(wAddr);           // send byte (address of EEPROM location)
    TWI_Write(wData);           // send data (data to be written)
    TWI_Stop();
}

//--------------- Reads data from 24AA01 EEPROM - single location (random)
unsigned short EEPROM_24AA01_RdSingle(unsigned short rAddr) {
    unsigned short reslt;

    TWI_Start();                // issue I2C1 start signal
    TWI_Write(0xA2);            // send byte via I2C1  (device address + W)
    TWI_Write(rAddr);           // send byte (data address)
    TWI_Stop();

    TWI_Start();
    TWI_Write(0xA3);            // send byte (device address + R)
    reslt = TWI_Read(0u);       // Read the data (NO acknowledge)
    while (TWI_Busy())
      asm nop;                  // Wait for the read cycle to finish
    TWI_Stop();
    return reslt;
}

//--------------- Reads data from 24AA01 EEPROM - sequential read
void EEPROM_24AA01_RdSeq(unsigned short rAddr,
                        unsigned char *rdData,
                        unsigned short rLen) {
  unsigned short i;
  TWI_Start();                  // issue I2C1 start signal
  TWI_Write(0xA2);              // send byte via I2C1  (device address + W)
  TWI_Write(rAddr);             // send byte (address of EEPROM location)
  TWI_Stop();

  TWI_Start();
  TWI_Write(0xA3);              // send byte (device address + R)
  i = 0;
  while (i < rLen) {
    rdData[i] = TWI_Read(1u);   // read data (acknowledge)
    Delay_ms(20);
    i++ ;
  }
  rdData[i] = TWI_Read(0u);     // last data is read (no acknowledge)
  TWI_Stop();
}
