/*
 * Project name:
     TWI_Advanced (Advanced TWI Example)
 * Copyright:
     (c) MikroElektronika, 2011.
 * Revision History:
     20110414:
       - initial release (FJ);
 * Description:
     This example features the advanced communication with the 24AA01 EEPROM chip
     by introducing its own library of functions for this task: init, single
     write, single and sequential read. It performs write of a sequence of bytes
     (characters) into the EEPROM and writes this out at the first row on Lcd.
     Then, data read from EEPROM is performed and the result is displayed at the
     second row on Lcd.
 * Test configuration:
     MCU:             ATMEGA128
                      http://www.atmel.com/dyn/resources/prod_documents/doc2467.pdf
     Dev.Board:       UNI-DS6 - ac:Serial_EEPROM
                      http://www.mikroe.com/eng/products/view/669/uni-ds6-development-system/
     Oscillator:      External Clock 10.0000 MHz
     Ext. Modules:    On-board Serial EEPROM module
                      LCD 2x16 module
     SW:              mikroC PRO for AVR
                      http://www.mikroe.com/eng/products/view/228/mikroc-pro-for-avr/
 * NOTES:
     - Turn on LCD/GLCD Control switches at SW15.5 and SW15.6 (board specific).
     - Turn on LCD Data switches at SW17 (board specific).
     - Turn on LCD backlight at SW18.7 (board specific).
     - Turn on I2C switches SW13.5 and SW13.6. (board specific)
     - Pull-up TWI communication lines (PD1 and PD2),
       place jumper J3 in upper position. (board specific)
     - Turn off PORTC LEDs (SW12.3). (board specific)
 */

#include "EEPROM_24AA01.h"

// LCD module connections
sbit LCD_RS at PORTB2_bit;
sbit LCD_EN at PORTB5_bit;
sbit LCD_D4 at PORTC4_bit;
sbit LCD_D5 at PORTC5_bit;
sbit LCD_D6 at PORTC6_bit;
sbit LCD_D7 at PORTC7_bit;

sbit LCD_RS_Direction at DDB2_bit;
sbit LCD_EN_Direction at DDB5_bit;
sbit LCD_D4_Direction at DDC4_bit;
sbit LCD_D5_Direction at DDC5_bit;
sbit LCD_D6_Direction at DDC6_bit;
sbit LCD_D7_Direction at DDC7_bit;
// End LCD module connections

char someData[] = "TWI mikroE";
char i ,tmpdata;

//  Main
void main() {

  EEPROM_24AA01_Init();                         // performs TWI initialization
  Lcd_Init();                                   // performs Lcd initialization
  Lcd_Cmd(_LCD_CLEAR);                          // clear Lcd
  Lcd_Cmd(_LCD_CURSOR_OFF);                     // set cursor off

  // Example for single-byte write
  i = 0;
  tmpdata = 1;
  while ((tmpdata = someData[i]) != 0) {
    i++;
    EEPROM_24AA01_WrSingle(i, tmpdata);         // writes data, char by char, in the EEPROM
    Delay_ms(20);
    Lcd_Chr(1,i, tmpdata);                      // diplays data on the first row of the Lcd
  }
  EEPROM_24AA01_WrSingle(i+1, 0);               // writes string termination
  Delay_ms(20);

  // Example for single-byte read
  i = 1;
  tmpdata = 1;
  while ((tmpdata = EEPROM_24AA01_RdSingle(i)) != 0) {
    Lcd_Chr(2,i, tmpdata);                      // displays data from EEPROM on the second row of the Lcd
    Delay_ms(20);
    i++ ;
  }
  
//  Example for sequential data read
//  Lcd_Cmd(_LCD_CLEAR);
//  EEPROM_24AA01_RdSeq(1, someData, 10);
//  Lcd_Out(2,1,someData);
}