 /*
 * Project name:
     TWI_Simple (Simple test of TWI library routines)
 * Copyright:
     (c) MikroElektronika, 2011.
 * Revision History:
     20110414:
       - initial release (FJ);
 * Description:
     This program demonstrates usage of the TWI library routines. It
     establishes TWI bus communication with 24AA01 EEPROM chip, writes one byte
     of data on some location, then reads it and displays it on PORTB.
 * Test configuration:
     MCU:             ATmega128
                      http://www.atmel.com/dyn/resources/prod_documents/doc2467.pdf
     Dev.Board:       UNI-DS6 - ac:Serial_EEPROM
                      http://www.mikroe.com/eng/products/view/669/uni-ds6-development-system/
     Oscillator:      External Clock 10.0000 MHz
     
     Ext. Modules:    on-board Serial EEPROM module
     SW:              mikroC PRO for AVR
                      http://www.mikroe.com/eng/products/view/228/mikroc-pro-for-avr/
 * NOTES:
     - Turn on I2C switches SW13.5 and SW13.6. (board specific)
     - Pull-up TWI communication lines (PD1 and PD2),
       place jumper J3 in upper position. (board specific)
     - Turn off PORTC LEDs (SW12.3). (board specific)
     - Turn on PORTB LEDs (SW12.2). (board specific)
*/

void main(){
  DDRB = 0xFF;
  PORTB = 0;                // Configure PORTB as output

  TWI_Init(100000);         // initialize TWI communication
  TWI_Start();              // issue TWI start signal
  TWI_Write(0xA2);          // send byte via TWI (device address + W)
  TWI_Write(2);             // send byte (address of EEPROM location)
  TWI_Write(0xAA);          // send data (data to be written)
  TWI_Stop();               // issue TWI stop signal

  Delay_100ms();

  TWI_Start();              // issue TWI start signal
  TWI_Write(0xA2);          // send byte via TWI (device address + W)
  TWI_Write(2);             // send byte (data address)
  TWI_Stop();               // issue TWI stop signal

  TWI_Start();              // issue TWI start signal
  TWI_Write(0xA3);          // send byte (device address + R)
  PORTB = TWI_Read(0u);     // Read the data (NO acknowledge)
  TWI_Stop();               // issue TWI stop signal
}