/*
 * Project name:
     USB UART2 (Simple usage of UART2 module library functions)
 * Copyright:
     (c) MikroElektronika, 2011.
 * Revision History:
     20110414:
       - initial release (FJ);
 * Description:
     This code demonstrates how to use UART2 library routines. Upon receiving
     data via RS232, MCU immediately sends it back to the sender.
 * Test configuration:
     MCU:             ATmega128
                      http://www.atmel.com/dyn/resources/prod_documents/doc2467.pdf
     Dev.Board:       UNI-DS6 - ac:UART2
                      http://www.mikroe.com/eng/products/view/669/uni-ds6-development-system/
     Oscillator:      External Clock 10.0000 MHz
     Ext. Modules:    -
     SW:              mikroC PRO for AVR
                      http://www.mikroe.com/eng/products/view/228/mikroc-pro-for-avr/
 * NOTES:
     - Turn on USB UART2 switches SW13.3 and SW13.4 (board specific).
*/

char uart_rd;

void main() {

  UART2_Init(9600);               // Initialize UART2 module at 9600 bps
  Delay_ms(100);                  // Wait for UART2 module to stabilize
  UART2_Write_Text("Ready");
  UART2_Write(13);                // Line Feed
  UART2_Write(10);                // Carriage Return
  
  while (1) {                     // Endless loop
    if (UART2_Data_Ready()) {     // If data is received,
      uart_rd = UART2_Read();     // Read the received data,
      UART2_Write(uart_rd);       // And send data via UART2
    }
  }
}