/*
 * Project name:
     Piezo Buzzer (Usage of Sound library)
 * Copyright:
     (c) MikroElektronika, 2011.
 * Revision History:
     20110414:
       - initial release (FJ);
 * Description:
     This project is a simple demonstration of how to
     use sound library for playing tones on a piezo speaker.
 * Test configuration:
     MCU:             PIC16F887
                      http://ww1.microchip.com/downloads/en/DeviceDoc/41291F.pdf
     Dev.Board:       UNI-DS6 - ac:Piezo
                      http://www.mikroe.com/eng/products/view/669/uni-ds6-development-system/
     Oscillator:      HS, 10.0000 MHz
     Ext. Modules:    -
     SW:              mikroC PRO for PIC
                      http://www.mikroe.com/eng/products/view/7/mikroc-pro-for-pic/
 * NOTES:
     - Connect jumper J14 to RC1. (board specific)
     - Put button jumper (J17) into VCC position and
       pull-down pins RC7...RC3 on PORTC. (board specific)
*/

void Tone1() {
  Sound_Play(659, 250);   // Frequency = 659Hz, duration = 250ms
}

void Tone2() {
  Sound_Play(698, 250);   // Frequency = 698Hz, duration = 250ms
}

void Tone3() {
  Sound_Play(784, 250);   // Frequency = 784Hz, duration = 250ms
}

void Melody() {           // Plays the melody "Yellow house"
  Tone1(); Tone2(); Tone3(); Tone3();
  Tone1(); Tone2(); Tone3(); Tone3();
  Tone1(); Tone2(); Tone3();
  Tone1(); Tone2(); Tone3(); Tone3();
  Tone1(); Tone2(); Tone3();
  Tone3(); Tone3(); Tone2(); Tone2(); Tone1();
}

void ToneA() {
  Sound_Play( 880, 50);
}
void ToneC() {
  Sound_Play(1046, 50);
}
void ToneE() {
  Sound_Play(1318, 50);
}

void Melody2() {
  unsigned short i;
  for (i = 9; i > 0; i--) {
    ToneA(); ToneC(); ToneE();
  }
}

void main() {

  ANSEL  = 0;                        // Configure AN pins as digital
  ANSELH = 0;
  C1ON_bit = 0;                      // Disable comparators
  C2ON_bit = 0;
  
  TRISC  = 0xF8;                     // Configure RC7..RC3 as input

  Sound_Init(&PORTC, 1);
  Sound_Play(880, 1000);             // Play sound at 880Hz for 1 second

  while (1) {
    if (Button(&PORTC,7,1,1))        // RC7 plays Tone1
      Tone1();
    while (RC7_bit) ;                // Wait for button to be released

    if (Button(&PORTC,6,1,1))        // RC6 plays Tone2
      Tone2();
    while (RC6_bit) ;                // Wait for button to be released

    if (Button(&PORTC,5,1,1))        // RC5 plays Tone3
      Tone3();
    while (RC5_bit) ;                // Wait for button to be released

    if (Button(&PORTC,4,1,1))        // RC4 plays Melody2
      Melody2();
    while (RC4_bit) ;                // Wait for button to be released

    if (Button(&PORTC,3,1,1))        // RC3 plays Melody
      Melody();
    while (RC3_bit) ;                // Wait for button to be released
  }
}