/*
 * Project name:
     ADC_on_LEDs (Demonstration of SPI communication with AD converter)
 * Copyright:
     (c) MikroElektronika, 2011.
 * Revision History:
     20110414:
       - initial release (FJ);
 * Description:
     This project is a simple demonstration of working with the 2.7V 4-Channel
     12-bit A/D Converter(MCP3204) with SPI Serial Interface.
     The values measured on Channel 0 are being displayed on PORTB LEDs in the 8-levels mode.
 * Test configuration:
     MCU:             dsPIC30F6014A
                      http://ww1.microchip.com/downloads/en/DeviceDoc/70143D.pdf
     Dev.Board:       UNI-DS6 - ac:ADC
                      http://www.mikroe.com/eng/products/view/669/uni-ds6-development-system/
     Oscillator:      XT-PLL8, 80.000MHz
     Ext. Modules:    None.
     SW:              mikroC PRO for dsPIC30/33 and PIC24
                      http://www.mikroe.com/eng/products/view/231/mikroc-pro-for-dspic30-33-and-pic24/
 * NOTES:
     - Turn on SPI1 switches on SW14.1, SW14.1 and SW14.3. (board specific)
     - Turn on ADC-CS on SW13.7. (board specific)
     - Turn on PORTB LEDs on SW12.2. (board specific)
     - Turn on +5V voltage reference on SW12.7. (board specific)
 */

# include <built_in.h>

sbit Chip_Select_Direction at TRISC1_bit;
sbit Chip_Select at LATC1_bit;

unsigned int measurement, lastValue;

void Init() {
  ADPCFG = 0xFFFF;                               // initialize AN pins as digital

  TRISB = 0;                                     // Init TRISB for output

  lastValue = 1;                                 // Initialize and make them
  measurement = 0;                               // different

  // Init SPI
  SPI1_Init();

  Chip_Select_Direction = 0;                     // ClearBit(TRISC, 1)
  Chip_Select= 1;                                // SetBit(LATC, 1)
}

unsigned int getADC(unsigned short channel) {    // Returns 0..4095
  unsigned int tmp;
  Chip_Select =0;                                // Select MCP3204
  SPI1_Write(0x06);                              // SPI communication using 8-bit segments
  channel = channel << 6;                        // Bits 7 & 6 define ADC input
  tmp = SPI1_Read(channel) & 0x0F;
  tmp = tmp << 8;                                // Get ADC value
  tmp |= SPI1_Read(0);
  Chip_Select =1;
  return tmp;
}

void processValue(unsigned int pv) {             // Writes measured values to LEDs in the 8-levels mode
  if (lastValue != pv) {                         // Write value only if different than previous

    lastValue = pv;

    // Converting the measured values into 8-levels mode
    pv = (pv >> 9) + 1;
    pv = (1 << pv) - 1;

    PORTB = Lo(pv);                              // Displaying the result on the PORTB
  }
}

// main procedure
void main() {

  Init();                                        // Initialize SPI

  while (1) {
    measurement = getADC(0);                     // Get ADC result from Channel 0
    ProcessValue(measurement);                   // Writing measured values to LEDs in the 8-levels mode
    Delay_ms(100);                               // Wait 100ms
  }
}