/*
 * Project name:
     Button_Test (Sample usage of Button() function)
 * Copyright:
     (c) MikroElektronika, 2011.
 * Revision History:
     20110414:
       - initial release (FJ);
 * Description:
     Simple demonstration on usage of the Button() function.
 * Test configuration:
     MCU:             dsPIC30F6014A
                      http://ww1.microchip.com/downloads/en/DeviceDoc/70143D.pdf
     Dev.Board:       UNI-DS6 - ac:Button
                      http://www.mikroe.com/eng/products/view/669/uni-ds6-development-system/
     Oscillator:      XT-PLL8, 80.000MHz
     Ext. Modules:    None.
     SW:              mikroC PRO for dsPIC30/33 and PIC24
                      http://www.mikroe.com/eng/products/view/231/mikroc-pro-for-dspic30-33-and-pic24/
 * NOTES:
     - Turn ON the PORTD LEDs on SW12. (board specific)
     - Put button jumper (J13) into VCC position and pull-down PORTB. (board specific)
 */

unsigned int oldstate;

void main() {

    oldstate = 0;
    ADPCFG   = 0xFFFF;                             // initialize AN pins as digital
    TRISB    = 0xFFFF;                             // initialize PORTB as input
    TRISD    = 0x0000;                             // initialize PORTD as output
    LATD     = 0xAAAA;
  
  do {
    if (Button(&PORTB, 0, 1, 1))                   // detect logical one on RB0 pin
      oldstate = 1;
    if (oldstate && Button(&PORTB, 0, 1, 0)) {     // detect one-to-zero transition on RB0 pin
      LATD = ~LATD;                                // invert PORTD value
      oldstate = 0;
    }
  } while(1);                                      // endless loop
}