/*
 * Project name:
     I2C_Simple (Simple test of I2C library routines)
 * Copyright:
     (c) MikroElektronika, 2011.
 * Revision History:
     20110414:
       - initial release (FJ);
 * Description:
     This program demonstrates usage of the I2C library routines. It
     establishes I2C bus communication with 24C02 EEPROM chip, writes one byte
     of data on some location, then reads it and displays it on PORTB.
 * Test configuration:
     MCU:             dsPIC30F6014A
                      http://ww1.microchip.com/downloads/en/DeviceDoc/70143D.pdf
     Dev.Board:       UNI-DS6 - ac:EEPROM
                      http://www.mikroe.com/eng/products/view/669/uni-ds6-development-system/
     Oscillator:      XT-PLL8, 80.000MHz
     Ext. Modules:    None.
     SW:              mikroC PRO for dsPIC30/33 and PIC24
                      http://www.mikroe.com/eng/products/view/231/mikroc-pro-for-dspic30-33-and-pic24/
 * NOTES:
     - Turn on I2C switches SW13.5 and SW13.6. (board specific)
     - Pull-up I2C communication lines (PD1 and PD2),
       place jumper J3 in upper position. (board specific)
     - Turn off PORTG LEDs (SW12.6). (board specific)
     - Turn on PORTD LEDs (SW12.4). (board specific)
 */
 
void main(){

  ADPCFG = 0xFFFF;            // initialize AN pins as digital

  LATD = 0;                   // Set PORTD value to zero
  TRISD = 0;                  // Configure PORTD as output

  I2C1_Init(100000);          // initialize I2C communication
  I2C1_Start();               // issue I2C start signal
  I2C1_Write(0xA2);           // send byte via I2C  (device address + W)
  I2C1_Write(2);              // send byte (address of EEPROM location)
  I2C1_Write(0xAA);           // send data (data to be written)
  I2C1_Stop();                // issue I2C stop signal

  Delay_100ms();

  I2C1_Start();               // issue I2C start signal
  I2C1_Write(0xA2);           // send byte via I2C  (device address + W)
  I2C1_Write(2);              // send byte (data address)
  I2C1_Restart();             // issue I2C signal repeated start
  I2C1_Write(0xA3);           // send byte (device address + R)
  LATD = I2C1_Read(1);        // Read the data (NO acknowledge)
  I2C1_Stop();                // issue I2C stop signal
}